@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.27'; # VERSION
+our $VERSION = '0.28'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -21,6 +21,8 @@ our @EXPORT_OK = qw(
                        linenum
                        pad
                        qqquote
+                       single_quote
+                       double_quote
                        common_prefix
                        common_suffix
                );
@@ -153,7 +155,7 @@ my %esc = (
 );
 
 # put a string value in double quotes
-sub qqquote {
+sub double_quote {
   local($_) = $_[0];
   # If there are many '"' we might want to use qq() instead
   s/([\\\"\@\$])/\\$1/g;
@@ -171,6 +173,20 @@ sub qqquote {
 }
 # END COPY PASTE FROM Data::Dump
 
+# old name, deprecated, will be removed in the future
+sub qqquote { goto &double_quote; }
+
+# will write this in the future, will produce "qq(...)" and "q(...)" literal
+# representation
+#sub qq_quote {}
+#sub q_quote {}
+
+sub single_quote {
+  local($_) = $_[0];
+  s/([\\'])/\\$1/g;
+  return qq('$_');
+}
+
 sub common_prefix {
     return undef unless @_;
     my $i;
@@ -220,7 +236,9 @@ SHARYANTO::String::Util - String utilities
 
 =head1 VERSION
 
-This document describes version 0.27 of SHARYANTO::String::Util (from Perl distribution SHARYANTO-String-Util), released on 2014-05-22.
+This document describes version 0.28 of SHARYANTO::String::Util (from Perl distribution SHARYANTO-String-Util), released on 2014-07-25.
+
+=for Pod::Coverage ^(qqquote)$
 
 =head1 FUNCTIONS
 
@@ -331,21 +349,33 @@ left+right padding to center the text.
 C<$padchar> is whitespace if not specified. It should be string having the width
 of 1 column.
 
-=head2 qqquote($str) => STR
+=head2 double_quote($str) => STR
 
-Quote or encode C<$str> to the Perl double quote (C<qq>) literal representation
+Quote or encode C<$str> to the Perl double quote (C<">) literal representation
 of the string. Example:
 
- say qqquote("a");        # => "a"
- say qqquote("a\n");      # => "a\n"
- say qqquote('"');        # => "\""
- say qqquote('$foo');     # => "\$foo"
+ say double_quote("a");        # => "a"     (with the quotes)
+ say double_quote("a\n");      # => "a\n"
+ say double_quote('"');        # => "\""
+ say double_quote('$foo');     # => "\$foo"
 
 This code is taken from C<quote()> in L<Data::Dump>. Maybe I didn't look more
 closely, but I couldn't a module that provides a function to do something like
 this. L<String::Escape>, for example, provides C<qqbackslash> but it does not
 escape C<$>.
 
+=head2 single_quote($str) => STR
+
+Like C<double_quote> but will produce a Perl single quote literal representation
+instead of the double quote ones. In single quotes, only literal backslash C<\>
+and single quote character C<'> are escaped, the rest are displayed as-is, so
+the result might span multiple lines or contain other non-printable characters.
+
+ say single_quote("Mom's");    # => 'Mom\'s' (with the quotes)
+ say single_quote("a\\");      # => 'a\\"
+ say single_quote('"');        # => '"'
+ say single_quote("\$foo");    # => '$foo'
+
 =head2 common_prefix(@LIST) => STR
 
 Given a list of strings, return common prefix.
